History
=======

0.0.1 (2021-05-21)
------------------

* Added REST Interface for:
    * subscription
    * unsubscription
    * microservice health status update
    * periodic service for microservice health status check
* Redis integration
